==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/events/MapAdminEventEntityFields.java <==
package org.keycloak.models.map.events;
public enum MapAdminEventEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.events.MapAdminEventEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setId((String) value);
        }
    },
    AUTH_CLIENT_ID {
        public static final String FIELD_NAME = "AuthClientId";
        public static final String FIELD_NAME_DASHED = "auth-client-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setAuthClientId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getAuthClientId();
        }
    },
    AUTH_IP_ADDRESS {
        public static final String FIELD_NAME = "AuthIpAddress";
        public static final String FIELD_NAME_DASHED = "auth-ip-address";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getAuthIpAddress();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setAuthIpAddress((String) value);
        }
    },
    AUTH_REALM_ID {
        public static final String FIELD_NAME = "AuthRealmId";
        public static final String FIELD_NAME_DASHED = "auth-realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getAuthRealmId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setAuthRealmId((String) value);
        }
    },
    AUTH_USER_ID {
        public static final String FIELD_NAME = "AuthUserId";
        public static final String FIELD_NAME_DASHED = "auth-user-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getAuthUserId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setAuthUserId((String) value);
        }
    },
    ERROR {
        public static final String FIELD_NAME = "Error";
        public static final String FIELD_NAME_DASHED = "error";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setError((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getError();
        }
    },
    EXPIRATION {
        public static final String FIELD_NAME = "Expiration";
        public static final String FIELD_NAME_DASHED = "expiration";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (Long) e.getExpiration();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setExpiration((Long) value);
        }
    },
    OPERATION_TYPE {
        public static final String FIELD_NAME = "OperationType";
        public static final String FIELD_NAME_DASHED = "operation-type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.events.admin.OperationType.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setOperationType((org.keycloak.events.admin.OperationType) value);
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.events.admin.OperationType get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (org.keycloak.events.admin.OperationType) e.getOperationType();
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getRealmId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setRealmId((String) value);
        }
    },
    REPRESENTATION {
        public static final String FIELD_NAME = "Representation";
        public static final String FIELD_NAME_DASHED = "representation";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getRepresentation();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setRepresentation((String) value);
        }
    },
    RESOURCE_PATH {
        public static final String FIELD_NAME = "ResourcePath";
        public static final String FIELD_NAME_DASHED = "resource-path";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getResourcePath();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setResourcePath((String) value);
        }
    },
    RESOURCE_TYPE {
        public static final String FIELD_NAME = "ResourceType";
        public static final String FIELD_NAME_DASHED = "resource-type";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setResourceType((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getResourceType();
        }
    },
    TIMESTAMP {
        public static final String FIELD_NAME = "Timestamp";
        public static final String FIELD_NAME_DASHED = "timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setTimestamp((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (Long) e.getTimestamp();
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/events/MapAdminEventEntityFields.java <==
package org.keycloak.models.map.events;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapAdminEventEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.events.MapAdminEventEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getId();
        }
    },
    AUTH_CLIENT_ID {
        public static final String FIELD_NAME = "AuthClientId";
        public static final String FIELD_NAME_DASHED = "auth-client-id";
        public static final String FIELD_NAME_CAMEL_CASE = "authClientId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getAuthClientId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setAuthClientId((String) value);
        }
    },
    AUTH_IP_ADDRESS {
        public static final String FIELD_NAME = "AuthIpAddress";
        public static final String FIELD_NAME_DASHED = "auth-ip-address";
        public static final String FIELD_NAME_CAMEL_CASE = "authIpAddress";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getAuthIpAddress();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setAuthIpAddress((String) value);
        }
    },
    AUTH_REALM_ID {
        public static final String FIELD_NAME = "AuthRealmId";
        public static final String FIELD_NAME_DASHED = "auth-realm-id";
        public static final String FIELD_NAME_CAMEL_CASE = "authRealmId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getAuthRealmId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setAuthRealmId((String) value);
        }
    },
    AUTH_USER_ID {
        public static final String FIELD_NAME = "AuthUserId";
        public static final String FIELD_NAME_DASHED = "auth-user-id";
        public static final String FIELD_NAME_CAMEL_CASE = "authUserId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setAuthUserId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getAuthUserId();
        }
    },
    ERROR {
        public static final String FIELD_NAME = "Error";
        public static final String FIELD_NAME_DASHED = "error";
        public static final String FIELD_NAME_CAMEL_CASE = "error";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setError((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getError();
        }
    },
    EXPIRATION {
        public static final String FIELD_NAME = "Expiration";
        public static final String FIELD_NAME_DASHED = "expiration";
        public static final String FIELD_NAME_CAMEL_CASE = "expiration";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setExpiration((Long) value);
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (Long) e.getExpiration();
        }
    },
    OPERATION_TYPE {
        public static final String FIELD_NAME = "OperationType";
        public static final String FIELD_NAME_DASHED = "operation-type";
        public static final String FIELD_NAME_CAMEL_CASE = "operationType";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return org.keycloak.events.admin.OperationType.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setOperationType((org.keycloak.events.admin.OperationType) value);
        }
        @SuppressWarnings("unchecked") @Override public org.keycloak.events.admin.OperationType get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (org.keycloak.events.admin.OperationType) e.getOperationType();
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        public static final String FIELD_NAME_CAMEL_CASE = "realmId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getRealmId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setRealmId((String) value);
        }
    },
    REPRESENTATION {
        public static final String FIELD_NAME = "Representation";
        public static final String FIELD_NAME_DASHED = "representation";
        public static final String FIELD_NAME_CAMEL_CASE = "representation";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getRepresentation();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setRepresentation((String) value);
        }
    },
    RESOURCE_PATH {
        public static final String FIELD_NAME = "ResourcePath";
        public static final String FIELD_NAME_DASHED = "resource-path";
        public static final String FIELD_NAME_CAMEL_CASE = "resourcePath";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getResourcePath();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setResourcePath((String) value);
        }
    },
    RESOURCE_TYPE {
        public static final String FIELD_NAME = "ResourceType";
        public static final String FIELD_NAME_DASHED = "resource-type";
        public static final String FIELD_NAME_CAMEL_CASE = "resourceType";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setResourceType((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (String) e.getResourceType();
        }
    },
    TIMESTAMP {
        public static final String FIELD_NAME = "Timestamp";
        public static final String FIELD_NAME_DASHED = "timestamp";
        public static final String FIELD_NAME_CAMEL_CASE = "timestamp";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Long.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Long get(org.keycloak.models.map.events.MapAdminEventEntity e) {
            return (Long) e.getTimestamp();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.events.MapAdminEventEntity e, T value) {
            e.setTimestamp((Long) value);
        }
    },
}
